@@ -66,13 +66,14 @@ class Repository:
         if not found_include:
           continue
         correct_path = found_include.path
-        if str(correct_path) != str(actual_path):
-          correct_path.parent.mkdir(exist_ok=True)
-          if not test:
-            actual_path.rename(correct_path)
-          cnt += 1
-          logging.info("Fixed %s -> %s", actual_path, correct_path)
-          type2cnt[type(found_include)] -= 1
+        if str(correct_path) == str(actual_path):
+          continue
+        correct_path.parent.mkdir(exist_ok=True)
+        if not test:
+          actual_path.rename(correct_path)
+        cnt += 1
+        logging.info("Fixed %s -> %s", actual_path, correct_path)
+        type2cnt[type(found_include)] -= 1
 
     logging.info("Left type2cnt %s", type2cnt)
     logging.info("%s wrong includes have been fixed", cnt)
@@ -206,14 +207,15 @@ class Include(IInclude):
     for line_num, txt in enumerate(file.path.read_text().split("\n"), 1):
       for cls_ in IInclude.__subclasses__():
         match = re.match(cls_.RE(), txt)
-        if match:
-          name = match.group(1)
-          include = cls_(file, name, line_num, txt)
-          if "|" in name and isinstance(cls_, Repo):
-            name, glob = name.split("|", 1)
-            name, glob = name.strip(" '\""), glob.strip(" '\"")
-            include.glob = glob
-          includes.append(include)
+        if not match:
+          continue
+        name = match.group(1)
+        include = cls_(file, name, line_num, txt)
+        if "|" in name and isinstance(cls_, Repo):
+          name, glob = name.split("|", 1)
+          name, glob = name.strip(" '\""), glob.strip(" '\"")
+          include.glob = glob
+        includes.append(include)
     return includes
 
   @staticmethod
@@ -249,16 +251,17 @@ class Repo(IInclude):
     for file_glob in self.glob.split("|"):
       lines += ["{% tabs %}"]
       for file in self.path.glob(file_glob):
-        if file.is_file() and file not in ignored and file.parent not in ignored:
-          lines += [f"{{% tab title=\'{file.relative_to(self.path)}\' %}}\n"]
-          suffix = file.suffix[1:]
-          lines += [f"````{suffix if suffix else 'txt'}"]
-          try:
-            lines += [file.read_text()]
-          except UnicodeDecodeError:
-            raise Exception("Please do not include binary files")
-          lines += ["````\n"]
-          lines += ["{% endtab %}"]
+        if not file.is_file() or file.name in ignored or file.parent.name in ignored:
+          continue
+        lines += [f"{{% tab title=\'{file.relative_to(self.path)}\' %}}\n"]
+        suffix = file.suffix[1:]
+        lines += [f"````{suffix if suffix else 'txt'}"]
+        try:
+          lines += [file.read_text()]
+        except UnicodeDecodeError:
+          raise Exception("Please do not include binary files")
+        lines += ["````\n"]
+        lines += ["{% endtab %}"]
       lines += ["{% endtabs %}\n"]
     return self.update_link("\n".join(lines))
 
